#
# spec file for package librevenge
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global apiversion 0.0
%global pkgextension 0_0-0
Name:           librevenge
Version:        0.0.5
Release:        1.5
Summary:        A base library for writing document import filters
License:        LGPL-2.1-or-later OR MPL-2.0
Group:          Development/Libraries/C and C++
URL:            https://sourceforge.net/p/libwpd/wiki/librevenge/
Source:         https://downloads.sourceforge.net/project/libwpd/%{name}/%{name}-%{version}/%{name}-%{version}.tar.xz
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} >= 1500
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif

%description
%{name} is a base library for writing document import filters. It has
interfaces for text documents, vector graphics, spreadsheets and
presentations.

%package -n %{name}-%{pkgextension}
Summary:        A base library for writing document import filters
License:        LGPL-2.1-or-later OR MPL-2.0
Group:          System/Libraries

%description -n %{name}-%{pkgextension}
%{name} is a base library for writing document import filters. It has
interfaces for text documents, vector graphics, spreadsheets and
presentations.

%package -n %{name}-stream-%{pkgextension}
Summary:        A base library for writing document import filters (stream implementations)
# src/lib/RVNGOLEStream.{h,cpp} are BSD3c
License:        BSD-3-Clause AND (LGPL-2.1-or-later OR MPL-2.0)
Group:          System/Libraries

%description -n %{name}-stream-%{pkgextension}
%{name} is a base library for writing document import filters. It has
interfaces for text documents, vector graphics, spreadsheets and
presentations.
This package contains the different stream implementations.

%package -n %{name}-generators-%{pkgextension}
Summary:        A base library for writing document import filters
License:        LGPL-2.1-or-later OR MPL-2.0
Group:          System/Libraries

%description -n %{name}-generators-%{pkgextension}
%{name} is a base library for writing document import filters. It has
interfaces for text documents, vector graphics, spreadsheets and
presentations.
This package contains classes to be used by converters that generate
documents using %{name}s APIs.

%package devel
Summary:        Development files for %{name}
License:        LGPL-2.1-or-later OR MPL-2.0
Group:          Development/Libraries/C and C++
Requires:       %{name}-%{pkgextension} = %{version}-%{release}
Requires:       %{name}-generators-%{pkgextension} = %{version}-%{release}
Requires:       %{name}-stream-%{pkgextension} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package doc
Summary:        Documentation of %{name} API
License:        LGPL-2.1-or-later OR MPL-2.0
Group:          Documentation/Other
BuildArch:      noarch

%description doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%setup -q

%build
%configure \
	--disable-static \
	--disable-werror \
	--enable-pretty-printers \
	--disable-silent-rules \
	--docdir=%{_docdir}/%{name}
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes -s %{buildroot}%{_docdir}/%{name}

%post -n %{name}-%{pkgextension} -p /sbin/ldconfig
%postun -n %{name}-%{pkgextension} -p /sbin/ldconfig
%post -n %{name}-stream-%{pkgextension} -p /sbin/ldconfig
%postun -n %{name}-stream-%{pkgextension} -p /sbin/ldconfig
%post -n %{name}-generators-%{pkgextension} -p /sbin/ldconfig
%postun -n %{name}-generators-%{pkgextension} -p /sbin/ldconfig

%check
%if 0%{?suse_version} >= 1500
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
make %{?_smp_mflags} check
%endif

%files -n %{name}-%{pkgextension}
%license COPYING.*
%doc README NEWS
%{_libdir}/%{name}-%{apiversion}.so.*

%files -n %{name}-stream-%{pkgextension}
%{_libdir}/%{name}-stream-%{apiversion}.so.*

%files -n %{name}-generators-%{pkgextension}
%{_libdir}/%{name}-generators-%{apiversion}.so.*

%files devel
%doc ChangeLog
%{_includedir}/%{name}-%{apiversion}

%{_libdir}/%{name}-%{apiversion}.so
%{_libdir}/%{name}-generators-%{apiversion}.so
%{_libdir}/%{name}-stream-%{apiversion}.so
%{_libdir}/pkgconfig/%{name}-%{apiversion}.pc
%{_libdir}/pkgconfig/%{name}-generators-%{apiversion}.pc
%{_libdir}/pkgconfig/%{name}-stream-%{apiversion}.pc
%dir %{_datadir}/gdb
%dir %{_datadir}/gdb/auto-load
%dir %{_datadir}/gdb/auto-load%{_prefix}
%dir %{_datadir}/gdb/auto-load%{_libdir}
%{_datadir}/gdb/auto-load%{_libdir}/%{name}-%{apiversion}-gdb.py*
%{_datadir}/gdb/auto-load%{_libdir}/%{name}-stream-%{apiversion}-gdb.py*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/python

%files doc
%license COPYING.*
%doc %{_docdir}/%{name}

%changelog
* Mon Jan 16 2023 Dirk Müller <dmueller@suse.com>
- update to 0.0.5:
  * Fix a bunch of issues discovered by oss-fuzz.
  * Require C++11 for building.
  * Modernize the code a bit.
  * Fix assignment of RVNGString from a C String. The previous code would
  append to the current content instead of replacing it.
  * When appending a characer to an RVNGString (i.e., using the char
    overload of
  append()), don't validate the character. Some libraries use this
  function to construct an RVNGString from UTF-8 code points.
  * Drop outdated MSVC project files.
  * Extend API documentation a bit.
  * Emit viewBox attribute for SVG output to fix user unit to ensure
  proper scaling.
  * More fixes for GDB pretty printers.
* Thu Jan 27 2022 Fridrich Strba <fstrba@suse.com>
- Fix license header to correspond to SPDX abbreviation
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Adjust SRPM group.
* Fri Aug 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Format a bit with spec-cleaner
- Do not run tests on SLE12 where they crash
* Thu Jun 13 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Co-own %%{_datadir}/gdb: so far we just relied on gcc9 in
  the build stack to coincidentially own this directory for us, but
  gcc9 split the gdb pretty printers out in a separate sub-package.
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Fri Apr 15 2016 dimstar@opensuse.org
- Do not BuildRequire gdb: there is no need to be ordered behind
  gdb in the build tree. Configure does check for the presence of
  the gdb binary, but the detected value is not used in the entire
  source tree.
* Tue Jan 12 2016 fstrba@suse.com
- Version bump to 0.0.4:
  * Fix possible crash in raw generators for unbalanced open/close
    calls.
  * Fix build in C++11 mode.
  * Fix gdb pretty printers and make them compatible with Python 3.
  * Fix RVNGString::Iter::last(), which only worked correctly for
    strings containing only ASCII characters.
  * Document the difference between RVNGString::len() and
    RVNGString::size().
  * Considerably improve performance of RVNGString iterator (a
    crude measurement shows at least 45%% improvement).
* Sat Dec 26 2015 fstrba@suse.com
- Version bump to 0.0.3:
  * SVG generator: fix the center of rotation.
  * Remove bashism in configure (libwpd#5).
  * Fix some syntax errors in documentation.
  * Text generator: handle footnotes and endnotes.
  * Improve performance of RVNGPropertyListVector::append() and
    RVNGBinaryData::append().
  * Fix several crashes or hangs when reading broken OLE2 or Zip
    files, found with the help of american-fuzzy-lop.
  * Fix build with boost 1.59 (libwpd#6).
  * Handle table:number-columns-repeated and
    table:number-rows-repeated in all spreadsheet generators.
  * CSV generator: handle rows with uneven number of columns
    correctly.
  * CSV generator: ignore empty rows at the end.
  * Several minor improvements and fixes.
* Wed Nov 11 2015 idonmez@suse.com
- Fix compilation with boost 1.59
* Fri Jan  2 2015 tchvatal@suse.com
- Version bump to 0.0.2:
  - Better handling of invalid input in RVNGDirectoryStream functions.
  - Add documentation for RVNGDirectoryStream.
  - Add text:outline-level to allowed paragraph properties. This is to allow
    import libraries to handle headings properly.
  - Properly handle units in all generators, instead of expecting everything is
    in inches.
  - Implement open/closeGroup for RVNGSVGDrawingGenerator.
  - Improve handling of layers in RVNGSVGPresentationGenerator.
  - Handle master pages in RVNGSVGDrawingGenerator and
    RVNGSVGPresentationGenerator.
  - Simple handling of tables in RVNGSVGDrawingGenerator and
    RVNGSVGPresentationGenerator: just create a text box for each cell.
  - Fix return value of RVNGStringStream::seek when seeking to end.
  - Fix some warnings found by Coverity.
  - Use symbol visibility on Linux. The library only exports public functions
    now.
  - Fix several crashes or hangs when reading broken OLE2 or Zip files, found
    with the help of american-fuzzy-lop.
  - Add fo:language, fo:country and fo:script to allowed span properties.
  - Handle headings in RVNGHTMLTextGenerator
* Tue Jul  1 2014 tchvatal@suse.com
- Add gdb dep to provide /usr/share/gdb directory
* Tue Jul  1 2014 tchvatal@suse.com
- Disable silent rules
* Tue Jul  1 2014 tchvatal@suse.com
- Add group
* Tue Jun  3 2014 fstrba@suse.com
- Upgrade to upstream 0.0.1 release
  * Fix license headers in some files.
  * Export API symbols on windows.
  * Really allow to disable build without streams and generators.
  * Detect CppUnit in configure already.
  * Drop dependency of librevenge-stream to Boost.Filesystem.
  * Do not throw exception when constructing RVNGDirectoryStream
    for an unexistent directory. Instead, create a valid dummy
    stream that will respond negatively to all operations (for
    consistency with RVNGFileStream).
  * Fix return type of RVNGBinaryData::getDataStream(). This change
    does affect neither API nor ABI.
  * Add some documentation for RVNGBinaryData.
  * Create a Coverity model covering the majority of librevenge data
    types, for the benefit of projects that use librevenge.
  * Several minor improvements and fixes.
- Remove upstreamed patches:
  * 0001-fix-type-sizes-for-CPPUNIT_ASSERT_EQUAL.patch
  * 0001-fix-license-headers-for-gdb-printers.patch
* Mon May 26 2014 fstrba@suse.com
- Initial package for librevenge
- 0001-fix-type-sizes-for-CPPUNIT_ASSERT_EQUAL.patch
  * fix make check on some architectures.
- 0001-fix-license-headers-for-gdb-printers.patch
  * pretty printers are licensed MPL-2.0 by their author.
